#
# spec file for package ceph-iscsi
#
# Copyright (C) 2017-2018 The Ceph iSCSI Project Developers. See
# COPYING file at the top-level directory of this distribution and at
# https://github.com/ceph/ceph-iscsi/blob/master/COPYING
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon.
#
# This file is under the GNU General Public License, version 3 or any
# later version.
#
# Please submit bugfixes or comments via http://tracker.ceph.com/
#
%if 0%{?rhel} == 7
%global with_python2 1
%endif

Name:           ceph-iscsi
Version:        3.5+1679292226.g8769429
Release:        1.5
Group:          System/Filesystems
Summary:        Python modules for Ceph iSCSI gateway configuration management
%if 0%{?suse_version}
License:        GPL-3.0-or-later
%else
License:        GPLv3+
%endif
URL:            https://github.com/ceph/ceph-iscsi
Source0:        %{name}-%{version}.tar.gz
%if 0%{?suse_version}
Source98:       checkin.sh
Source99:       README-checkin.txt
ExclusiveArch:  x86_64 aarch64 ppc64le s390x
%endif

Obsoletes:      ceph-iscsi-config
Obsoletes:      ceph-iscsi-cli

Requires:       tcmu-runner >= 1.4.0
Requires:       ceph-common >= 10.2.2
%if 0%{?with_python2}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
Requires:       python-rados >= 10.2.2
Requires:       python-rbd >= 10.2.2
Requires:       python-netifaces >= 0.10.4
Requires:       python-rtslib >= 2.1.fb68
Requires:       python-cryptography
Requires:       python-flask >= 0.10.1
Requires:       python-configshell
%if 0%{?rhel} == 7
Requires:       pyOpenSSL
Requires:       python-requests
%else
Requires:       python-pyOpenSSL
Requires:       python2-requests
%endif
%else
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-rados >= 10.2.2
Requires:       python3-rbd >= 10.2.2
Requires:       python3-netifaces >= 0.10.4
Requires:       python3-rtslib >= 2.1.fb68
Requires:       python3-cryptography
Requires:       python3-pyOpenSSL
Requires:       python3-requests
%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
BuildRequires:  fdupes
Requires:       python3-Flask >= 0.10.1
Requires:       python3-configshell-fb
%else
Requires:       python3-flask >= 0.10.1
Requires:       python3-configshell
%endif
%endif

%if 0%{?rhel}
BuildRequires: systemd
%else
BuildRequires: systemd-rpm-macros
%{?systemd_requires}
%endif

%if 0%{?suse_version}
Conflicts: lrbd < 3.0
%endif

%description
Python package providing the modules used to handle the configuration of an
iSCSI gateway, backed by Ceph RBD. The RPM installs configuration management
logic (ceph_iscsi_config modules), an rbd-target-gw systemd service, and
a CLI-based management tool 'gwcli', replacing the 'targetcli' tool.

The configuration management modules may be are consumed by custom Ansible
playbooks and the rbd-target-gw daemon.

The rbd-target-gw service is responsible for startup and shutdown actions,
replacing the 'target' service used in standalone LIO implementations.
In addition, rbd-target-gw also provides a REST API utilized by the Ceph
dashboard and gwcli tool, and a prometheus exporter for gateway LIO
performance statistics, supporting monitoring and visualisation tools like
Grafana.

%prep
%autosetup -p1

%build
%if 0%{?with_python2}
%{__python2} setup.py build
%else
%if 0%{?suse_version}
%python3_build
%else
%{py3_build}
%endif
%endif

%install
%if 0%{?with_python2}
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}  --install-scripts %{_bindir}
%else
%if 0%{?suse_version}
%python3_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%else
%{py3_install}
%endif
%endif
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 .%{_unitdir}/rbd-target-gw.service %{buildroot}%{_unitdir}
install -m 0644 .%{_unitdir}/rbd-target-api.service %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_mandir}/man8
install -m 0644 gwcli.8 %{buildroot}%{_mandir}/man8/
gzip %{buildroot}%{_mandir}/man8/gwcli.8
mkdir -p %{buildroot}%{_unitdir}/rbd-target-gw.service.d
%if 0%{?suse_version}
mkdir -p %{buildroot}%{_sbindir}
ln -s service %{buildroot}%{_sbindir}/rcrbd-target-gw
ln -s service %{buildroot}%{_sbindir}/rcrbd-target-api
%endif

%pre
%if 0%{?suse_version}
%service_add_pre rbd-target-gw.service rbd-target-api.service
%endif

%post
%if 0%{?rhel} == 7
/bin/systemctl --system daemon-reload &> /dev/null || :
/bin/systemctl --system enable rbd-target-gw &> /dev/null || :
/bin/systemctl --system enable rbd-target-api &> /dev/null || :
%endif
%if 0%{?fedora} || 0%{?rhel} >= 8
%systemd_post rbd-target-gw.service
%systemd_post rbd-target-api.service
%endif
%if 0%{?suse_version}
%service_add_post rbd-target-gw.service rbd-target-api.service
%endif

%preun
%if 0%{?fedora} || 0%{?rhel} >= 8
%systemd_preun rbd-target-gw.service
%systemd_preun rbd-target-api.service
%endif
%if 0%{?suse_version}
%service_del_preun rbd-target-gw.service rbd-target-api.service
%endif

%postun
%if 0%{?rhel} == 7
/bin/systemctl --system daemon-reload &> /dev/null || :
%endif
%if 0%{?fedora} || 0%{?rhel} >= 8
%systemd_postun rbd-target-gw.service
%systemd_postun rbd-target-api.service
%endif
%if 0%{?suse_version}
%service_del_postun rbd-target-gw.service rbd-target-api.service
%endif

%files
%license LICENSE
%license COPYING
%doc README
%doc iscsi-gateway.cfg_sample
%if 0%{?with_python2}
%{python2_sitelib}/*
%else
%{python3_sitelib}/*
%endif
%{_bindir}/gwcli
%{_bindir}/rbd-target-gw
%{_bindir}/rbd-target-api
%{_unitdir}/rbd-target-gw.service
%{_unitdir}/rbd-target-api.service
%{_mandir}/man8/gwcli.8.gz
%attr(0770,root,root) %dir %{_localstatedir}/log/rbd-target-gw
%attr(0770,root,root) %dir %{_localstatedir}/log/rbd-target-api
%dir %{_unitdir}/rbd-target-gw.service.d
%if 0%{?suse_version}
%{_sbindir}/rcrbd-target-gw
%{_sbindir}/rcrbd-target-api
%endif

%changelog
* Mon Mar 20 2023 Tim Serong <tserong@suse.com>
- Update to 3.5+1679292226.g8769429:
  + rbd-target-api: don't ignore controls on disk create (bsc#1208820)
- checkin.sh: default to ses7 branch
* Thu Jun 16 2022 Stefen Allen <stefen.allen@suse.com>
- Update to 3.5+1655410541.gf482c7a.
  + Improve werkzeug version checking (bsc#1198435)
* Fri Mar 18 2022 Stefen Allen <stefen.allen@suse.com>
- Update to 3.5+1647618797.gb7bc626.
  + ceph_iscsi_config: disable emulate_legacy_capacity (bsc#1179557)
* Thu Dec  2 2021 Stefen Allen <stefen.allen@suse.com>
- Update to 3.5+1638408991.g5341b5d
  + rbd unmap image when deleting target (bsc#1190772)
  + gwcli: add error handling path for config api request (#231)
  + rbd-target-api: misc fixing for disk API (#229)
  + iscsi: raise if the 'gateway.conf' config file doesn't exist (#228)
  + iscsi: write cert/key to temp files in mode 'w' to handle strings (#227)
  + Fix the default value for gateway_conf (#226)
  + Add a strip to ListSetting.Normalize (#220, bsc#1177100)
  + Make settings mon config key store aware (#217)
  + Rename blacklist to blocklist (#216)
  + Fix gateway creation crash in python3 (#196)
  + Report tcmu-runner device status (#210)
  + Fix list access violiation when load config (#200, bsc#1183028)
  + fix delete disk error when disk owner is not specified (#206)
  + Support specified gateway config name (#207)
  + spec: added dependency on ceph-common package (#201)
* Wed Feb 24 2021 Ricardo Marques <rimarques@suse.com>
- Update to 3.4+1614165221.g78e33bb
  + Gateway fails to start when using SSL (bsc#1182611)
* Fri Oct 16 2020 Ricardo Marques <rimarques@suse.com>
- Update to 3.4+1602850653.g9af452e
  + Support spaces on 'trusted_ip_list' (#220, bsc#1177100)
* Wed Oct 14 2020 Ricardo Marques <rimarques@suse.com>
- Update to 3.4+1602668899.ga7b4d38
  + Update RBD supported features for SLE15-SP2 kernel (bsc#1177202)
  + Make settings mon config key store aware (#217)
* Thu May 14 2020 Ricardo Marques <rimarques@suse.com>
- Update to 3.4+1589469085.ga007663
  + Add a config option to log to stderr (#186)
  + Don't store to config if create_target fails (#187)
  + Fixed numerous string format issues on errors paths (#189)
* Thu Apr 30 2020 Ricardo Marques <rimarques@suse.com>
- Update to 3.4+1588266755.g4a5a2cb
  + Attempt to pull SSL crt and key's from mon config-key store (#173)
* Tue Apr 14 2020 Ricardo Marques <rimarques@suse.com>
- Update to 3.4+1586869678.gf041d18
  + Allow target reconfigure without clients (bsc#1164571)
  + Fix ceph blacklist ls test (#171)
  + Always perform full deletion on local node (#170)
  + Fix crash during unblacklisting with python3 (#170)
  + Fix metrics crash if gw not setup yet (#170)
  + Fix keys() crash with python 3 (#168)
  + Add option to force deletion of unreachable gw (#156)
  + Fix next() crash with python 3 (#164)
  + Fix config upgrade from 2 to 3 (#162)
  + Fix ZeroDivisionError (#155)
* Fri Nov 15 2019 Ricardo Marques <rimarques@suse.com>
- Update to 3.3+1573833100.g55d02da:
  + Allow explicit set LUN number and WWN (bsc#1145756)
  + Should be possible to use a single gateway (bsc#1155283)
  + Fix group disk add on python3
  + Fix crash when CephCluster fails to get Rados object
* Tue Oct  8 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.3+1570534953.g93940a4:
  + spec/checkin.sh:
  * reinstate "BuildArch: noarch" for all distros except openSUSE (i.e.,
    including SLE, which does not allow arch change in a maintenance update)
  * "ExclusiveArch" on openSUSE only
* Fri Sep 27 2019 Ricardo Marques <rimarques@suse.com>
- Update to 3.3+1569576525.g93940a4:
  + Validate kernel LIO controls type and value (bsc#1140491)
  + TPG lun_id persistence (bsc#1145618)
  + Target level CHAP authentication (bsc#1145617)
* Thu Sep 26 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.2+1569497618.ga2b17e1:
  + incremental pre-Milestone1 build
* Tue Sep 10 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.2+1568098374.g09c5205:
  + upstream 3.2 release
  * Always use host FQDN instead of shortname
  * Validate min/max value for target controls and rbd:user/tcmu-runner image
    controls (bsc#1140491)
  + checkin.sh:
  * add "sed" statements to reproduce Dominique Leuenberger's
    downstream-only mod from July 29, 2019 (see previous entry), so it
    doesn't get clobbered every time we run the script
  * add "sed" statement to collapse multiple newlines down to one
* Mon Jul 29 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Make package not noarch: it is not installable on archs where
  ceph is not being built. Copy the ExclusiveArch statement from
  ceph.spec.
* Tue Jun 11 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1560249372.g70ec7a9:
  + spec: drop python3-configshell-fb version guard
* Mon Jun 10 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1560181178.g3010fd7:
  + Fix config hash check validation
  + spec: fix rhel conditional blocks
* Thu Jun  6 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1559837868.g8be74cf:
  + spec: conflict only with lrbd <= 3.0 to ensure lrbd is not installed
    simultaneously with ceph-iscsi
* Thu Jun  6 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1559815396.g7aa8f7f:
  + Set 'SUSE' SCSI vendor (bsc#1136769)
  + Adds support for multiple IPs per gateway (bsc#1136757)
  + Do not allow lrbd to be installed simultaneously with ceph-iscsi
  + Temporary workaround to support ',' in configshell params (must be removed/reverted in the future, after configshell >= 1.1.f25 is available)
  + Fix problem deleting target with clients/disks
  + Removes the disk 'delete' command
* Tue May 21 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1558465738.g6a0a021:
  + If fqdn is enabled, "getfqdn" should be used instead of "gethostname"
* Tue May 21 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1558443949.g9784103:
  + rbd-target-gw/api systemd dep fix
  + Add support for enabling FQDN
* Thu May  9 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1557415271.g940ac86:
  + Fix race condition on target disk add (bsc#1134479)
* Thu May  9 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1557397680.g929bd14:
  + logger level is now configurable
  + tcmu-runner supports all RBD features
  + allow deletion of a target that doesn't exist in LIO
* Mon Apr 29 2019 Nathan Cutler <ncutler@suse.com>
- Update to 3.0+1556546618.g28a0e8a:
  + Should be possible to export config without targets
  + Prevent error getting the number of active sessions
  + Fix race condition in '_targetauth' config update
  + Fix error when trying to get client info from 'gwcli'
* Mon Apr  8 2019 ncutler@suse.com
- Update to 3.0+1554735444.g63aceaf:
  + Adds endpoints:
  * /api/targetinfo/<target_iqn>
  * /api/gatewayinfo
  * /api/clientinfo/<target_iqn>/<client_iqn>
  + Fix upgrade from config v3 when 'controls' field is missing
* Mon Mar 25 2019 ncutler@suse.com
- Update to 3.0+1553528639.g1149ac6:
  + '/settings' endpoint return required and support RBD features by backstore
  + Enable/disable 'demo_mode_write_protect' when enabling/disabling ACL authentication
* Wed Mar 20 2019 ncutler@suse.com
- Update to 3.0+1553076762.g61c150a:
  + Gateway management fixes and features
  + regression: fix lun reconfigure failure
* Fri Mar 15 2019 ncutler@suse.com
- Update to 3.0+1552644320.g118bce3:
  + Fix chap config update
  + Always use rados client name when connecting to Ceph cluster
  + spec: add python-configshell runtime dependency
  + gw: use client id when calling ceph shell command
  + Fix race condition after gateway creation
  + Misc target/acl reconfigure fixes
* Mon Mar 11 2019 ncutler@suse.com
- Update to 3.0+1552304123.g67b0d30:
  + add support for 'rbd' backstore (Ricardo Marques)
* Thu Feb 28 2019 ncutler@suse.com
- Update to 3.0+1551350485.g157b5fd:
  + refactor spec file for better Fedora/RHEL and Python 3 support (Ricardo Dias)
  + rados pool for storing configuration is now configurable (Ricardo Marques)
  + support for specifying the cluster client name (Ricardo Dias)
* Tue Feb 19 2019 ncutler@suse.com
- Update to 3.0+1550592273.gda1fd9b:
  + Support for kernel LIO backstore (which is the default backstore on SES6)
    (Ricardo Marques)
  + Disable OS, and package version checks (Ricardo Marques)
* Thu Feb  7 2019 ncutler@suse.com
- checkin.sh: append git SHA1 to version number
* Mon Feb  4 2019 ncutler@suse.com
- Update to 3.0+1549277704:
  + based on upstream master SHA1 17023339c03f8a8ad289db7689f6d6424c2b860f
  * packaging: Move python unbuffered option to systemd unit file
    (bsc#1123070)
* Thu Jan 17 2019 ncutler@suse.com
- checkin.sh: ensure tarballs are uniquely named
* Wed Jan 16 2019 ncutler@suse.com
- multiple iSCSI target support (Ricardo Marques)
* Fri Dec  7 2018 ncutler@suse.com
- migrate from python3-pycrypto to python3-cryptography
  (Ricardo Dias)
* Wed Dec  5 2018 ncutler@suse.com
- spec: use correct package name for python3-Flask dependency
* Mon Nov 19 2018 ncutler@suse.com
- Add support for Python3 (Ricardo Marques)
* Wed Nov 14 2018 ncutler@suse.com
- Initial commit, based on SUSE/ceph-iscsi.git branch "ses6",
  SHA1 9c04ed0c3fe7a9ad057b3bb676f5f07cf97270fc
  (upstream 0b9046105d900ca03249d044ce759c12efa5a016)
